package com.fastbee.crop.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.crop.mapper.AgricultureCropInfoMapper;
import com.fastbee.crop.domain.AgricultureCropInfo;
import com.fastbee.crop.service.IAgricultureCropInfoService;

/**
 * 农作物信息管理Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-11-26
 */
@Service
public class AgricultureCropInfoServiceImpl implements IAgricultureCropInfoService 
{
    @Autowired
    private AgricultureCropInfoMapper agricultureCropInfoMapper;

    /**
     * 查询农作物信息管理
     * 
     * @param id 农作物信息管理主键
     * @return 农作物信息管理
     */
    @Override
    public AgricultureCropInfo selectAgricultureCropInfoById(Long id)
    {
        return agricultureCropInfoMapper.selectAgricultureCropInfoById(id);
    }

    /**
     * 查询农作物信息管理列表
     * 
     * @param agricultureCropInfo 农作物信息管理
     * @return 农作物信息管理
     */
    @Override
    public List<AgricultureCropInfo> selectAgricultureCropInfoList(AgricultureCropInfo agricultureCropInfo)
    {
        return agricultureCropInfoMapper.selectAgricultureCropInfoList(agricultureCropInfo);
    }

    /**
     * 新增农作物信息管理
     * 
     * @param agricultureCropInfo 农作物信息管理
     * @return 结果
     */
    @Override
    public int insertAgricultureCropInfo(AgricultureCropInfo agricultureCropInfo)
    {
        return agricultureCropInfoMapper.insertAgricultureCropInfo(agricultureCropInfo);
    }

    /**
     * 修改农作物信息管理
     * 
     * @param agricultureCropInfo 农作物信息管理
     * @return 结果
     */
    @Override
    public int updateAgricultureCropInfo(AgricultureCropInfo agricultureCropInfo)
    {
        return agricultureCropInfoMapper.updateAgricultureCropInfo(agricultureCropInfo);
    }

    /**
     * 批量删除农作物信息管理
     * 
     * @param ids 需要删除的农作物信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAgricultureCropInfoByIds(Long[] ids)
    {
        return agricultureCropInfoMapper.deleteAgricultureCropInfoByIds(ids);
    }

    /**
     * 删除农作物信息管理信息
     * 
     * @param id 农作物信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAgricultureCropInfoById(Long id)
    {
        return agricultureCropInfoMapper.deleteAgricultureCropInfoById(id);
    }
}
